@@ -3,8 +3,9 @@ import logging
 import uologging
 
 logger = logging.getLogger(__name__)
+trace = uologging.trace(logger)
 
 
-@uologging.trace(logger)
+@trace
 def hello():
     print('hello from example2!')
