@@ -40,5 +40,23 @@ def test_trace_dont_capture_secret_arguments(caplog):
         # Act
         test_method('SuperSecretPassword')
 
-    # Assert - May fail on very slow computers...
+    # Assert
     assert_that(caplog.text).does_not_contain('SuperSecretPassword')
+
+
+def test_trace_capture_arguments(caplog):
+    # Arrange
+    with caplog.at_level(logging.DEBUG):
+        uologging.init_console_logging()
+        logger = logging.getLogger(__name__)
+
+        @uologging.trace(logger)
+        def test_method(arg, another_arg=None):
+            pass
+
+        # Act
+        test_method('Bird', 
+                    another_arg=['is', 'the', 'word!'])
+
+    # Assert
+    assert_that(caplog.text).contains("test_method('Bird', another_arg=['is', 'the', 'word!'])")
